#ifndef _CtiRtxSerial_h
#define _CtiRtxSerial_h


// Hardware flow control mask used by HardwareFlow of UCB
#define FLOW_RTS		0x01	//enable RTS flow control
#define FLOW_CTS		0x02	//enable CTS flow control
#define FLOW_DTR		0x04	//enable DTR flow control
#define FLOW_DSR		0x08	//enable DSR flow control
//
// Define a Universal Asynchronous Receiver/Transmitter (UART) Control Block
//     
typedef  struct
{     
   LONG		baudRate; 	// configured baud rate
   char		parity;	 // parity (none=n, even=e, odd=o mark=m, space=s)
   BYTE		stopBits;	// 0 1 or 2 stop bits   
   BYTE		wordSize; 	// word size..5 - 8 bits
   BOOL		bSoftwareFlow;	//boolean value indicates whether software flow control will be used
	BYTE		XoffChar;	//Xoff byte value, default 0x13
	BYTE		XonChar;	//Xon byte value, default 0x11
	BYTE		HardwareFlow;	//Bits indicate mode as described above
	BYTE		BH485Mode;	// 3 indicates RS-485 Multidrop
								// 2 indicates RS-485 Half-Duplex
								// 1 indicates RS485 Full duplex										
								// 0 RS-232 default
}UCB;

/********************************************************************************
* The following is the mask value of LSR as defined for standard 550 UART       *
* GetLsr and GetError will return LSR mask value                                *
* The GetError will not read LSR register, it is ORed value of previous errors  *
* due to LSR errors and driver buffer overrun											  *
********************************************************************************/
// This bit is the data ready indicator.  It is set to indicate that
// a complete character has been received.  This bit is cleared whenever
// the receive buffer register has been read.

#define SERIAL_LSR_DR       0x01


// This is the overrun indicator.  It is set to indicate that the receive
// buffer register was not read befor a new character was transferred
// into the buffer.  This bit is cleared when this register is read.

#define SERIAL_LSR_OE       0x02


// This is the parity error indicator.  It is set whenever the hardware
// detects that the incoming serial data unit does not have the correct
// parity as defined by the parity select in the line control register.
// This bit is cleared by reading this register.

#define SERIAL_LSR_PE       0x04


// This is the framing error indicator.  It is set whenever the hardware
// detects that the incoming serial data unit does not have a valid
// stop bit.  This bit is cleared by reading this register.

#define SERIAL_LSR_FE       0x08


// This is the break interrupt indicator.  It is set whenever the data
// line is held to logic 0 for more than the amount of time it takes
// to send one serial data unit.  This bit is cleared whenever the
// this register is read.

#define SERIAL_LSR_BI       0x10

// This is the transmit holding register empty indicator.  It is set
// to indicate that the hardware is ready to accept another character
// for transmission.  This bit is cleared whenever a character is
// written to the transmit holding register.

#define SERIAL_LSR_THRE     0x20

// This bit is the transmitter empty indicator.  It is set whenever the
// transmit holding buffer is empty and the transmit shift register
// (a non-software accessable register that is used to actually put
// the data out on the wire) is empty.  Basically this means that all
// data has been sent.  It is cleared whenever the transmit holding or
// the shift registers contain data.

#define SERIAL_LSR_TEMT     0x40

// This bit indicates that there is at least one error in the fifo.
// The bit will not be turned off until there are no more errors
// in the fifo.

#define SERIAL_LSR_FIFOERR  0x80

/*********************END of LSR Mask*******************************************/
/*******************************************************************************/


/********************************************************************************
* The following is the mask value of MSR as defined for standard 550 UART       *
* GetMsr will return MSR mask value                                             *
********************************************************************************/

// This bit is the delta clear to send.  It is used to indicate
// that the clear to send bit (in this register) has *changed*
// since this register was last read by the CPU.

#define SERIAL_MSR_DCTS     0x01

// This bit is the delta data set ready.  It is used to indicate
// that the data set ready bit (in this register) has *changed*
// since this register was last read by the CPU.

#define SERIAL_MSR_DDSR     0x02

// This is the trailing edge ring indicator.  It is used to indicate
// that the ring indicator input has changed from a low to high state.

#define SERIAL_MSR_TERI     0x04

// This bit is the delta data carrier detect.  It is used to indicate
// that the data carrier bit (in this register) has *changed*
// since this register was last read by the CPU.

#define SERIAL_MSR_DDCD     0x08

//
// This bit contains the (complemented) state of the clear to send
// (CTS) line.
//
#define SERIAL_MSR_CTS      0x10

//
// This bit contains the (complemented) state of the data set ready
// (DSR) line.
//
#define SERIAL_MSR_DSR      0x20

//
// This bit contains the (complemented) state of the ring indicator
// (RI) line.
//
#define SERIAL_MSR_RI       0x40

//
// This bit contains the (complemented) state of the data carrier detect
// (DCD) line.
//
#define SERIAL_MSR_DCD      0x80

/*********************END of MSR Mask*******************************************/
/*******************************************************************************/

/********************************************************************************
* The following is the mask value of DTR RTS	returned by GetDtrRts		        *
********************************************************************************/

#define SERIAL_DTR_STATE         ((ULONG)0x00000001)
#define SERIAL_RTS_STATE         ((ULONG)0x00000002)

/*********************END of DTR RTS Mask***************************************/
/*******************************************************************************/




/********************************************************************************
*********************************************************************************
***** Export library API declaration by ctirtxserial.obj ************************
********************************************************************************/

// This library API will open a BlueStorm serial port
HANDLE
_stdcall
Open(
    PCHAR	lpName			// BlueStorm device driver name as \RtDevice\BlueStorm\SerialX where X is the port index
    );

// This library API will close from BlueStorm serial port
BOOL
_stdcall
Close(
    HANDLE	hDriver			// Handle from RtdDeviceOpen
    );

// This library API will read data from BlueStorm serial port
LONG 
_stdcall
Read(
	HANDLE hDriver,		// Handle from RtdDeviceOpen
	BYTE *buffer,			// buffer pointer for read buffer
	ULONG bytesToRead		// number of bytes to read
	);

// This library API will write data to BlueStorm serial port
LONG 
_stdcall
Write(
	HANDLE hDriver, 		// Handle from RtdDeviceOpen
	BYTE *buffer,			// buffer pointer for write buffer  
	ULONG bytesToWrite	// number of bytes to write
	);

// This library API will return the number of bytes available for read request 
LONG 
_stdcall
GetReadCount(
	HANDLE hDriver
	);

// This library API will setup BlueStorm serial port
BOOL
_stdcall
Setup(
    HANDLE	hDriver,		// Handle from RtdDeviceOpen
	 UCB	portSettings	// Initialized UCB structure
    );

// This library API will set RTS for a BlueStorm serial port
VOID
_stdcall
SetRts(
    HANDLE	hDriver	
    );

// This library API will clear RTS for a BlueStorm serial port
VOID
_stdcall
ClrRts(
    HANDLE	hDriver
    );

// This library API will set DTR for a BlueStorm serial port
VOID
_stdcall
SetDtr(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 
    );

// This library API will clear DTR for a BlueStorm serial port
VOID
_stdcall
ClrDtr(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 
    );

// This library API will get MSR of a BlueStorm serial port

BYTE
_stdcall
GetMsr(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 	 
    );

// This library API will get LSR of a BlueStorm serial port
BYTE
_stdcall
GetLsr(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 	 
    );

// This library API will get DTR RTS status of a BlueStorm serial port
BYTE
_stdcall
GetDtrRts(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 	 
    );

// This library API will set Break for a BlueStorm serial port
VOID
_stdcall
SetBreak(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 	 	
    );

// This library API will clear Break for a BlueStorm serial port
VOID
_stdcall
ClrBreak(
    HANDLE	hDriver		// Handle from RtdDeviceOpen	 	 	
    );

// This library API will get LSR error for a BlueStorm serial port

BYTE 
_stdcall 
GetError(
	HANDLE hDriver			// Handle from RtdDeviceOpen	 	 
	);

#endif