/**********************************************************************************
********** sample for operating BlueStorm driver **************************************
The following sample only shows how to use the some exported API by BlueStorm driver.
**********************************************************************************/



#include <windows.h>
#include <stdio.h>
#include <conio.h>
#include "rtapi.h"
#include "ctirtxserial.h"

#define BUF_SIZE		1024

#define MAXTRIES		20



int
main(
	int argc,
	char* argv[])
{
   HANDLE			hDriver;				// handle to BlueStorm port
	UCB				portSettings;		// required structure for Setup API
	char				*portName="\\RtDevice\\Bstorm\\Serial0\0";	// BlueStorm port
	BYTE				buffer[BUF_SIZE]; // buffer for read/write
	ULONG				retVal;	//return value to check for read/write operation
	ULONG				count, retries;
	
	//initialize to some default values
	portSettings.baudRate = 9600; // 9600 baudrate
	portSettings.parity = 'n';		// parity none
	portSettings.stopBits = 1;		// stop bits 1 bit
	portSettings.wordSize = 8;		// word size 8 bits
	portSettings.HardwareFlow = FLOW_RTS|FLOW_CTS; // RTS/CTS flow control
	portSettings.bSoftwareFlow = FALSE; //no software flow control
	portSettings.XonChar = 0x11;	// Xon character
	portSettings.XoffChar = 0x13;	// Xoff character
	portSettings.BH485Mode = 0;		//RS-232 mode

	
	//
	// Open the  ports
	//
	hDriver = Open(portName);
	
	if (hDriver==NULL)
	{
		RtPrintf("BlueStorm driver open failure (error=%d).\n", GetLastError());
		RtPrintf("The BlueStorm driver is probably not loaded.\n");			
		return 1;
	}
		
	//
	// Setup the port with desired baudrate and line settings
	if(!Setup(hDriver, portSettings))
	{
		RtPrintf("Port Settings parameters are invalid\n");
		return 1;
	}
	
	// set RTS
	SetRts(hDriver);
	// set DTR
	SetDtr(hDriver);
	
	// sleep for 100 ms
	Sleep(100);	
	
	//prepare the write buffer
	for(count = 0; count < BUF_SIZE; count++)		
	{
		buffer[count] = (BYTE) count % 26 + 0x41;		
	}	
	// write some data to port
	retVal = Write(hDriver, buffer, BUF_SIZE);	

	RtPrintf("Sent %d bytes\n", retVal);
	
	//try for 2 second to drain the write buffer
	retries = 0;
	while(1)
	{
		retVal = GetReadCount(hDriver);	
		if (retVal < BUF_SIZE)
		{				
			Sleep(100);
			retries++;
			if(retries > MAXTRIES)
				break;
			else
				continue;				
		}
		else
			break;
	}

	// read data from port
	retVal = Read(hDriver, buffer, BUF_SIZE);	
	RtPrintf("Read %d bytes\n", retVal);
	for(count = 0; count < retVal; count++)			
		RtPrintf("%c",buffer[count]);

	// clear RTS
	ClrRts(hDriver);
	// clear DTR
	ClrDtr(hDriver);
	//
	// Close the  ports.
	//
	if (!Close( hDriver))
	{
		RtPrintf("BlueStorm driver close failure (error=%d).\n", GetLastError());			
	}

	
	return 1;
}


